==> react-image-annotate_ns_demo-4.0.44.tgz: package/Sidebar/index.js <==
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { styled } from "@mui/styles";
import React from "react";
import DebugBox from "../DebugSidebarBox";
import History from "../HistorySidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import TaskDescription from "../TaskDescriptionSidebarBox";
var theme = createTheme();
var Container = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {};
});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref2) {
  var debug = _ref2.debug,
      taskDescription = _ref2.taskDescription,
      keyframes = _ref2.keyframes,
      images = _ref2.images,
      regions = _ref2.regions,
      history = _ref2.history,
      labelImages = _ref2.labelImages,
      currentImage = _ref2.currentImage,
      currentVideoTime = _ref2.currentVideoTime,
      imageClsList = _ref2.imageClsList,
      imageTagList = _ref2.imageTagList,
      onChangeImage = _ref2.onChangeImage,
      onSelectRegion = _ref2.onSelectRegion,
      onSelectImage = _ref2.onSelectImage,
      onChangeRegion = _ref2.onChangeRegion,
      onDeleteRegion = _ref2.onDeleteRegion,
      _onRestoreHistory = _ref2.onRestoreHistory,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      onDeleteKeyframe = _ref2.onDeleteKeyframe,
      onShortcutActionDispatched = _ref2.onShortcutActionDispatched;
  if (!regions) regions = emptyArr;
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(Container, null, debug && /*#__PURE__*/React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && /*#__PURE__*/React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && /*#__PURE__*/React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), /*#__PURE__*/React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion
  }), keyframes && /*#__PURE__*/React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  }), /*#__PURE__*/React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  })));
};
export default Sidebar;

==> react-image-annotate_ns_demo-5.0.11.tgz: package/Sidebar/index.js <==
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { styled } from "@mui/styles";
import React from "react";
import DebugBox from "../DebugSidebarBox";
import History from "../HistorySidebarBox";
import KeyframesSelector from "../KeyframesSelectorSidebarBox";
import RegionSelector from "../RegionSelectorSidebarBox";
import TagsSidebarBox from "../TagsSidebarBox";
import TaskDescription from "../TaskDescriptionSidebarBox";
var theme = createTheme();
var Container = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {};
});
var emptyArr = [];
export var Sidebar = function Sidebar(_ref2) {
  var debug = _ref2.debug,
      taskDescription = _ref2.taskDescription,
      keyframes = _ref2.keyframes,
      images = _ref2.images,
      regions = _ref2.regions,
      history = _ref2.history,
      labelImages = _ref2.labelImages,
      currentImage = _ref2.currentImage,
      currentVideoTime = _ref2.currentVideoTime,
      imageClsList = _ref2.imageClsList,
      imageTagList = _ref2.imageTagList,
      onChangeImage = _ref2.onChangeImage,
      onSelectRegion = _ref2.onSelectRegion,
      onSelectImage = _ref2.onSelectImage,
      onChangeRegion = _ref2.onChangeRegion,
      onDeleteRegion = _ref2.onDeleteRegion,
      _onRestoreHistory = _ref2.onRestoreHistory,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      onDeleteKeyframe = _ref2.onDeleteKeyframe,
      onShortcutActionDispatched = _ref2.onShortcutActionDispatched,
      delete_annotation = _ref2.delete_annotation,
      setdelete_annotation = _ref2.setdelete_annotation;
  if (!regions) regions = emptyArr;
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(Container, null, debug && /*#__PURE__*/React.createElement(DebugBox, {
    state: debug,
    lastAction: debug.lastAction
  }), taskDescription && (taskDescription || "").length > 1 && /*#__PURE__*/React.createElement(TaskDescription, {
    description: taskDescription
  }), labelImages && /*#__PURE__*/React.createElement(TagsSidebarBox, {
    currentImage: currentImage,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    onChangeImage: onChangeImage,
    expandedByDefault: true
  }), /*#__PURE__*/React.createElement(RegionSelector, {
    regions: regions,
    onSelectRegion: onSelectRegion,
    onChangeRegion: onChangeRegion,
    onDeleteRegion: onDeleteRegion,
    delete_annotation: delete_annotation,
    setdelete_annotation: setdelete_annotation
  }), keyframes && /*#__PURE__*/React.createElement(KeyframesSelector, {
    currentVideoTime: currentVideoTime,
    keyframes: keyframes,
    onChangeVideoTime: onChangeVideoTime,
    onDeleteKeyframe: onDeleteKeyframe
  }), /*#__PURE__*/React.createElement(History, {
    history: history,
    onRestoreHistory: function onRestoreHistory() {
      return _onRestoreHistory();
    }
  })));
};
export default Sidebar;
